<?php

namespace Drupal\cludo_search\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a cludo_search block for the search form.
 *
 * @Block(
 *   id = "cludo_search",
 *   admin_label = @Translation("Cludo Search block"),
 *   category = @Translation("Cludo Search")
 * )
 */
class CludoSearchBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $form = \Drupal::formBuilder()->getForm('Drupal\cludo_search\Form\CludoSearchBlockForm');

    // Add JS and CSS.
    $form['#attached']['library'][] = 'cludo_search/cludo-customer';

    // Define variables and add to JS.
    $settings = _cludo_search_get_settings();
    $disable_autocomplete = $settings['disable_autocomplete'] ? TRUE : FALSE;
    $hide_results = $settings['hide_results_count'] ? TRUE : FALSE;
    $hide_did_you_mean = $settings['hide_did_you_mean'] ? TRUE : FALSE;
    $hide_search_filters = $settings['hide_search_filters'] ? TRUE : FALSE;
    $search_url = \Drupal::request()->getSchemeAndHttpHost() . '/' . $settings['search_page'];
    $form['#attached']['drupalSettings']['cludo_search']['cludo_searchJS'] = [
      'customerId' => $settings['customerId'],
      'engineId' => $settings['engineId'],
      'searchUrl' => $search_url,
      'disableAutocomplete' => $disable_autocomplete,
      'hideResultsCount' => $hide_results,
      'hideSearchDidYouMean' => $hide_did_you_mean,
      'hideSearchFilters' => $hide_search_filters,
    ];

    return $form;
  }

}
